==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QStyleFactory_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWidgets/qstylefactory.h>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtWidgets/qstyle.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStyleFactory(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleFactory")
    QStyleFactory *_ptr = reinterpret_cast<QStyleFactory *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QStyleFactory()
void __qt_construct_QStyleFactory(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleFactory()")
    Q_UNUSED(__java_arguments)
    QStyleFactory *__qt_this = new(__qtjambi_ptr) QStyleFactory();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QStyleFactory::QStyleFactory()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleFactory_initialize_1native__Lio_qt_widgets_QStyleFactory_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleFactory::QStyleFactory()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleFactory, sizeof(QStyleFactory), typeid(QStyleFactory), false, &deleter_QStyleFactory, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStyleFactory
void __qt_destruct_QStyleFactory(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleFactory")
    reinterpret_cast<QStyleFactory*>(ptr)->~QStyleFactory();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStyleFactory::create(QString)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleFactory_create__Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jstring arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleFactory::create(QString)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QString  __qt_arg__1 = qtjambi_cast<QString>(__jni_env, arg__1);
        QStyle* __qt_return_value = QStyleFactory::create(__qt_arg__1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStyleFactory::keys()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleFactory_keys__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleFactory::keys()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QStringList __qt_return_value = QStyleFactory::keys();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QStyleFactory(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QStyleFactory>("QStyleFactory", "io/qt/widgets/QStyleFactory");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStyleFactory, {
        ConstructorInfo(&__qt_construct_QStyleFactory, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleFactory);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiWidgets/QStyleFactory_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWidgets/qstylefactory.h>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtWidgets/qstyle.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStyleFactory(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleFactory")
    QStyleFactory *_ptr = reinterpret_cast<QStyleFactory *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QStyleFactory()
void __qt_construct_QStyleFactory(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleFactory()")
    Q_UNUSED(__java_arguments)
    QStyleFactory *__qt_this = new(__qtjambi_ptr) QStyleFactory();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QStyleFactory::QStyleFactory()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleFactory_initialize_1native__Lio_qt_widgets_QStyleFactory_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleFactory::QStyleFactory()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleFactory, sizeof(QStyleFactory), typeid(QStyleFactory), 0, false, &deleter_QStyleFactory, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStyleFactory
void __qt_destruct_QStyleFactory(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleFactory")
    reinterpret_cast<QStyleFactory*>(ptr)->~QStyleFactory();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStyleFactory::create(QString)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleFactory_create__Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jstring arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleFactory::create(QString)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QString __qt_arg__1 = qtjambi_cast<QString>(__jni_env, arg__1);
        QStyle* __qt_return_value = QStyleFactory::create(__qt_arg__1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QStyleFactory::keys()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleFactory_keys__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleFactory::keys()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QStringList __qt_return_value = QStyleFactory::keys();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QStyleFactory(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QStyleFactory>("QStyleFactory", "io/qt/widgets/QStyleFactory");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QStyleFactory, {
        ConstructorInfo(&__qt_construct_QStyleFactory, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleFactory);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
